TITAN_TITANBG_ID = "TitanBG";
TITAN_TITANBG_FREQUENCY = 0.5;
TITANBG_ARTWORK_PATH = "Interface\\AddOns\\TitanBG\\Artwork\\";
TITANBG_BLUETEXT = "|cff0070dd";

local _last_event_check = 0;
local _evet_check_delay = 5;
local _autojoin_time = 0;
local _autojoin_paused = 0;
local _autojoin_delay = 10;
local _bginfo = { };
local _friendlist = { };
local _friendasked = false;
local _friendstring = "";
local _localmap = { };
local _capture_delay = 300;
local _instanceruntime = 0;
local _soundplayed = false;
local _playerstats = { };

function TitanPanelTitanBGButton_OnLoad()
	this.registry = {
		id = TITAN_TITANBG_ID,
		menuText = TITANBG_MENU_TEXT,
		buttonTextFunction = "TitanPanelTitanBGButton_GetButtonText", 
		tooltipTitle = TITANBG_TOOLTIP, 
		tooltipTextFunction = "TitanPanelTitanBGButton_GetTooltipText",
		icon = TITANBG_ARTWORK_PATH.."TitanBG",		
		iconWidth = 16,
		frequency = TITAN_TITANBG_FREQUENCY, 
		savedVariables = {
			ShowIcon = 1,
			ShowLabelText = 1,
			HideMinimapButton = 0,
			B_AutoJoin = 0,
			B_AutoRes = 0,
			B_AutoRelease = 0,
			B_PlaySoundOnJoin = 0,
			D_Friends = 1,
			D_Capture = 1,
			P_Labels = 1,
			P_K = 1,
			P_KB = 1,
			P_D = 1,
			P_H = 1,
			P_S = 1,
		}
	};

	this:RegisterEvent("FRIENDLIST_UPDATE");
end

function TitanPanelTitanBGButton_OnEvent()
	if (event == "FRIENDLIST_UPDATE") then
		local nFriends = GetNumFriends();
		_friendlist = { };
		local indexf;
		for indexf=1, nFriends do
			local fname,_,_,_,_ = GetFriendInfo(indexf);
			_friendlist[fname] = 1;
		end
	end
end

function TitanPanelTitanBGButton_CheckMap()
	local marks = GetNumMapLandmarks();

	for i = 1, marks, 1 do
		local name, description, txture, x, y = GetMapLandmarkInfo(i);

		if ( not _localmap[name] ) then
			_localmap[name] = {};
		end

		_localmap[name].txture = txture;
		_localmap[name].x = x;
		_localmap[name].y = y;

		if ( txture == 3 or txture == 8 or txture == 9 or txture == 12 or txture == 19 or txture == 20 or txture == 24 or txture == 25
			 or txture == 29 or txture == 30 or txture == 34 or txture == 35 or txture == 39 or txture == 40) then
			_localmap[name].faction = "Horde";
		elseif ( txture == 10 or txture == 11 or txture == 13 or txture == 14 or txture == 17 or txture == 18 or txture == 22 or txture == 23
			or txture == 27 or txture == 28 or txture == 32 or txture == 33 or txture == 37 or txture == 38) then
			_localmap[name].faction = "Alliance";
		end

		if (txture == 3 or txture == 13 or txture == 8 or txture == 11) then
			if ( not _localmap[name].capture ) then
				_localmap[name].capture = GetTime() + _capture_delay;
			end
		elseif (txture == 17 or txture == 22 or txture == 27 or txture == 32 or txture == 37 or txture == 19 or txture == 24 or txture == 29
			 or txture == 34 or txture == 39) then
			 if ( not _localmap[name].capture ) then
			 	_localmap[name].capture = GetTime() + 60;
			 end
		else
			_localmap[name].capture = nil;
		end
	end
end

function TitanPanelTitanBGButton_IsControled(txture)
	if (txture == 3 or txture == 13 or txture == 8 or txture == 11) then
		return false;
	else
		return true;
	end
end

function TitanPanelTitanBGButton_IsGraveYard(txture)
	if (txture == 3 or txture == 12 or txture == 13 or txture == 14) then
		return true;
	else
		return false;
	end
end

function TitanPanelTitanBGButton_CheckEvents()
	local status, name, _ = GetBattlefieldStatus();
	local pName = UnitName("player");

	if ( status == "queued" or status == "active" or status == "confirm" ) then
		if ( TitanGetVar(TITAN_TITANBG_ID, "HideMinimapButton") ) then
			MiniMapBattlefieldFrame:Hide();
		else
			MiniMapBattlefieldFrame:Show();
		end
	end

	if ( status ~= "active" ) then
		_bginfo = { };
		_instanceruntime = 0;
		_playerstats = { };
	elseif ( status ~= "confirm" ) then
		_autojoin_time = 0;
		_autojoin_paused = 0;
		_soundplayed = false;
	end

	if ( not _friendasked and status == "active" ) then
		ShowFriends();
		_friendasked = true;
	end

	if ( not _soundplayed and TitanGetVar(TITAN_TITANBG_ID, "B_PlaySoundOnJoin") and status == "confirm" ) then
		PlaySoundFile("Interface\\AddOns\\TitanBG\\bgr.wav");
		_soundplayed = true;
	end

	if ( status == "confirm" and _autojoin_time > GetTime() and _autojoin_paused > 0 ) then
		_autojoin_time = GetTime() + _autojoin_paused;
	end

	if ( status == "confirm" and _autojoin_time ~= 0 and _autojoin_time < GetTime() ) then
		if ( TitanGetVar(TITAN_TITANBG_ID, "B_AutoJoin") ) then
			BattlefieldFrame_EnterBattlefield();
			StaticPopup_Hide("CONFIRM_BATTLEFIELD_ENTRY");
			_autojoin_time = 0;
		end
	end

	if ( UnitIsDeadOrGhost("player") ) then
		TitanPanelTitanBGButton_AutoRes();
		TitanPanelTitanBGButton_AutoRelease();
	end

	if ( _last_event_check + _evet_check_delay < GetTime() ) then
		RequestBattlefieldScoreData();
		_last_event_check = GetTime();

		if ( status == "active" ) then
			TitanPanelTitanBGButton_CheckMap()
			_friendstring = "";
			_instanceruntime = GetBattlefieldInstanceRunTime();
			_playerstats = { };
			_playerstats.total = 0;
			_playerstats.h = 0;
			_playerstats.a = 0;

			for i=1, 80 do
				local name, killingblows, kills, deaths, honorgained, faction, rank, race, class = GetBattlefieldScore(i);
				if ( class ~= nil ) then
					_playerstats.total = _playerstats.total + 1;

					if ( faction ) then
						if ( faction == 0 ) then
							_playerstats.h = _playerstats.h + 1;	
						else
							_playerstats.a = _playerstats.a + 1;
						end
					end
				else
					break;
				end

				if ( name == pName ) then
					_bginfo = { };
					_bginfo.standing = i;
					_bginfo.kills = kills;
					_bginfo.deaths = deaths;
					_bginfo.killingblows = killingblows;
					_bginfo.honorgained = honorgained;
					_bginfo.faction = faction;
					_bginfo.rank = rank;
					_bginfo.race = race;
					_bginfo.class = class;
				elseif ( _friendlist[name] and TitanGetVar(TITAN_TITANBG_ID, "D_Friends") ) then
					_friendstring = _friendstring.."\n"..name.."\t";
					_friendstring = _friendstring..TitanUtils_GetHighlightText("#: ")..TitanUtils_GetGreenText(i)..", ";
					_friendstring = _friendstring..TitanUtils_GetHighlightText(TITANBG_S_KILLINGBLOWS)..TitanUtils_GetGreenText(killingblows)..", ";
					_friendstring = _friendstring..TitanUtils_GetHighlightText(TITANBG_S_KILLS)..TitanUtils_GetGreenText(kills)..", ";
					_friendstring = _friendstring..TitanUtils_GetHighlightText(TITANBG_S_DEATHS)..TitanUtils_GetRedText(deaths);
				end
			end

			if ( _bginfo.standing and name == "Alterac Valley" ) then
				local sColumns = GetNumBattlefieldStats();
				for j=1, MAX_NUM_STAT_COLUMNS do
					if ( j <= sColumns ) then
						local cData = GetBattlefieldStatData(_bginfo.standing, j);
						if (j == 1) then
							_bginfo.gyassaulted = cData;
						elseif (j == 2) then
							_bginfo.gydefended = cData;
						elseif (j == 3) then
							_bginfo.tassaulted = cData;
						elseif (j == 4) then
							_bginfo.tdefended = cData;
						elseif (j == 5) then
							_bginfo.mcaptured = cData;
						elseif (j == 6) then
							_bginfo.lkilled = cData;
						elseif (j == 7) then
							_bginfo.secobj = cData;
						end
					end
				end
			elseif ( _bginfo.standing and name == "Warsong Gulch" ) then
				local sColumns = GetNumBattlefieldStats();
				for j=1, MAX_NUM_STAT_COLUMNS do
					if ( j <= sColumns ) then
						local cData = GetBattlefieldStatData(_bginfo.standing, j);
						if (j == 1) then
							_bginfo.fcaptured = cData;
						elseif (j == 2) then
							_bginfo.freturned = cData;
						end
					end
				end
			end
		end
	end
end

function TitanPanelTitanBGButton_AutoRes()
	if ( TitanGetVar(TITAN_TITANBG_ID, "B_AutoRes") ) then
		local status, _, _ = GetBattlefieldStatus();
		if ( status == "active" ) then
			if ( UnitIsGhost("player") ) then
				AcceptAreaSpiritHeal();

				for index = 1, STATICPOPUP_NUMDIALOGS, 1 do
					local frame = getglobal("StaticPopup"..index);
					if ( frame:IsVisible() and frame.which == "AREA_SPIRIT_HEAL" ) then
						getglobal("StaticPopup"..index.."Button1"):Hide();
						getglobal("StaticPopup"..index.."Button2"):Hide();
					end
				end
			end
		end
	end
end

function TitanPanelTitanBGButton_AutoRelease()
	if ( TitanGetVar(TITAN_TITANBG_ID, "B_AutoRelease") ) then
		local status, _, _ = GetBattlefieldStatus();
		if ( status == "active" ) then
			RepopMe();
		end
	end
end

function TitanPanelTitanBGButton_OnClick(button)
	if ( button == "LeftButton" ) then
		if (_autojoin_time > GetTime() and _autojoin_paused == 0) then
			_autojoin_paused = _autojoin_time - GetTime();
			return;
		end

		if (_autojoin_paused > 0) then
			_autojoin_paused = 0;
		end

		local status, _, _ = GetBattlefieldStatus();
		if ( status == "active" and TitanGetVar(TITAN_TITANBG_ID, "HideMinimapButton") ) then
			ToggleWorldStateScoreFrame();
		end
	end
end

function TitanPanelTitanBGButton_DoLabel(t)
	if ( TitanGetVar(TITAN_TITANBG_ID, "P_Labels") ) then
		return t;
	end
	return "";
end

function TitanPanelTitanBGButton_GetButtonText()
	TitanPanelTitanBGButton_CheckEvents();

	local pName = UnitName("player");
	local status, name, instance = GetBattlefieldStatus();

	if ( status == "none" ) then
		return TitanUtils_GetHighlightText(TITANBG_NOT_IN_QUEUE);
	elseif ( status == "queued" ) then
		if ( instance == 0 ) then
			name = TitanUtils_GetHighlightText(name)..TitanUtils_GetGreenText(" ["..TITANBG_FIRST_AVAILABLE.."]");
		else
			name = TitanUtils_GetHighlightText(name)..TitanUtils_GetGreenText(" ["..TITANBG_INSTANCE.." "..instance.."]");
		end
		return TitanPanelTitanBGButton_DoLabel(TITANBG_LABEL_IN_QUEUE)..name;
	elseif ( status == "confirm" ) then
		if ( TitanGetVar(TITAN_TITANBG_ID, "B_AutoJoin") and _autojoin_time == 0 ) then
			_autojoin_time = GetTime() + _autojoin_delay;
		end

		if ( TitanGetVar(TITAN_TITANBG_ID, "B_AutoJoin") and _autojoin_time > GetTime() ) then
			return TitanPanelTitanBGButton_DoLabel(TITANBG_LABEL_READY)..TitanUtils_GetHighlightText(TITANBG_JOINING_IN..SecondsToTime(_autojoin_time - GetTime()));
		else
			return TITANBG_LABEL_READY;
		end
	elseif ( status == "active" ) then
		if ( _bginfo.standing ) then
			local pText = "";

			if ( TitanGetVar(TITAN_TITANBG_ID, "P_S") ) then
				pText = pText..TitanPanelTitanBGButton_DoLabel(TITANBG_S_STANDING)..TitanUtils_GetHighlightText(_bginfo.standing).." ";
			end
			if ( TitanGetVar(TITAN_TITANBG_ID, "P_KB") ) then
				pText = pText..TitanPanelTitanBGButton_DoLabel(TITANBG_S_KILLINGBLOWS)..TitanUtils_GetGreenText(_bginfo.killingblows).." ";
			end
			if ( TitanGetVar(TITAN_TITANBG_ID, "P_K") ) then
				pText = pText..TitanPanelTitanBGButton_DoLabel(TITANBG_S_KILLS)..TitanUtils_GetGreenText(_bginfo.kills).." ";
			end
			if ( TitanGetVar(TITAN_TITANBG_ID, "P_D") ) then
				pText = pText..TitanPanelTitanBGButton_DoLabel(TITANBG_S_DEATHS)..TitanUtils_GetRedText(_bginfo.deaths).." ";
			end
			if ( TitanGetVar(TITAN_TITANBG_ID, "P_H") ) then
				pText = pText..TitanPanelTitanBGButton_DoLabel(TITANBG_S_HONOR)..TitanUtils_GetHighlightText(_bginfo.honorgained).." ";
			end

			if ( pText == "" ) then
				pText = "TitanBG";
			end
			
			return pText;

			--return "#: ", TitanUtils_GetHighlightText(_bginfo.standing), TITANBG_S_KILLINGBLOWS, TitanUtils_GetGreenText(_bginfo.killingblows),
			--	TITANBG_S_KILLS, TitanUtils_GetGreenText(_bginfo.kills), TITANBG_S_DEATHS, TitanUtils_GetRedText(_bginfo.deaths);
		else
			return TitanUtils_GetHighlightText(TITANBG_NO_INFORMATION);
		end	
	end
end

function TitanPanelTitanBGButton_GetTooltipText()
	local pName = UnitName("player");
	local status, name, instance = GetBattlefieldStatus();

	if ( status == "none" ) then
		return TitanUtils_GetHighlightText(TITANBG_NOT_IN_QUEUE);
	elseif ( status == "queued" ) then
		local wTime = GetBattlefieldEstimatedWaitTime();
		local inQueue = GetBattlefieldTimeWaited();
		local wtInfo = ""..TITANBG_ESTIMATED_WAIT;

		if ( wTime == 0 ) then
			wtInfo = wtInfo.."\t"..TitanUtils_GetRedText(TITANBG_UNAVAILABLE);
		elseif ( wTime < 60000 ) then
			wtInfo = wtInfo.."\t"..TitanUtils_GetGreenText(TITANBG_LESS_THAN_ONE_MIN);
		else
			wtInfo = wtInfo.."\t"..TitanUtils_GetHighlightText(SecondsToTime(wTime / 1000, 1));
		end

		wtInfo = wtInfo.."\n"..TITANBG_TIME_IN_QUEUE.."\t"..TitanUtils_GetHighlightText(SecondsToTime(inQueue / 1000));

		if ( wTime > inQueue ) then
			wtInfo = wtInfo.."\n"..TITANBG_ESTIMATED_REMAINING.."\t"..TitanUtils_GetHighlightText(SecondsToTime((wTime - inQueue) / 1000));
		end

		return wtInfo;
	elseif ( status == "confirm" ) then
		local cInfo = TITANBG_LABEL_READY;
		if( _autojoin_time > 0 ) then
			cInfo = cInfo.."\n"..TitanUtils_GetGreenText(TITANBG_AUTOJOIN_HINT);
		end
		return cInfo;
	elseif ( status == "active" ) then
		local bInfo = TitanUtils_GetHighlightText(name.." "..instance);
		if ( _instanceruntime > 0 ) then
			bInfo = bInfo.."\t"..TitanUtils_GetGreenText(SecondsToTime(_instanceruntime/1000, 1));
		end
		bInfo = bInfo.."\n\n";

		if ( _bginfo.standing ) then
			bInfo = bInfo..TitanUtils_GetHighlightText(TITANBG_PLAYER_STATS);
			bInfo = bInfo.."\n"..TITANBG_PLAYER_STANDING.."\t"..TitanUtils_GetHighlightText(_bginfo.standing);
			bInfo = bInfo.."\n"..TITANBG_PLAYER_KILLINGBLOWS.."\t"..TitanUtils_GetGreenText(_bginfo.killingblows);
			bInfo = bInfo.."\n"..TITANBG_PLAYER_KILLS.."\t"..TitanUtils_GetGreenText(_bginfo.kills);
			bInfo = bInfo.."\n"..TITANBG_PLAYER_DEATHS.."\t"..TitanUtils_GetRedText(_bginfo.deaths);
			bInfo = bInfo.."\n"..TITANBG_PLAYER_BONUSHONOR.."\t"..TitanUtils_GetGreenText(_bginfo.honorgained);

			if ( _bginfo.gyassaulted ) then
				bInfo = bInfo.."\n";
				bInfo = bInfo.."\n"..TITANBG_PLAYER_GYASSAULTED.."\t"..TitanUtils_GetGreenText(_bginfo.gyassaulted);
				bInfo = bInfo.."\n"..TITANBG_PLAYER_GYDEFENDED.."\t"..TitanUtils_GetGreenText(_bginfo.gydefended);
				bInfo = bInfo.."\n"..TITANBG_PLAYER_TASSAULTED.."\t"..TitanUtils_GetGreenText(_bginfo.tassaulted);
				bInfo = bInfo.."\n"..TITANBG_PLAYER_TDEFENDED.."\t"..TitanUtils_GetGreenText(_bginfo.tdefended);
				bInfo = bInfo.."\n"..TITANBG_PLAYER_MCAPTURED.."\t"..TitanUtils_GetHighlightText(_bginfo.mcaptured);
				bInfo = bInfo.."\n"..TITANBG_PLAYER_LKILLED.."\t"..TitanUtils_GetHighlightText(_bginfo.lkilled);
				bInfo = bInfo.."\n"..TITANBG_PLAYER_SECOBJ.."\t"..TitanUtils_GetHighlightText(_bginfo.secobj);
			end

			if ( _bginfo.fcaptured ) then
				bInfo = bInfo.."\n";
				bInfo = bInfo.."\n"..TITANBG_PLAYER_FCAPTURED.."\t"..TitanUtils_GetGreenText(_bginfo.fcaptured);
				bInfo = bInfo.."\n"..TITANBG_PLAYER_FRETURNED.."\t"..TitanUtils_GetGreenText(_bginfo.freturned);
			end
		else
			bInfo = bInfo..TitanUtils_GetHighlightText(TITANBG_NO_INFORMATION);
		end

		if ( TitanGetVar(TITAN_TITANBG_ID, "D_Friends") and _friendstring ~= "" ) then
			bInfo = bInfo.."\n\n"..TitanUtils_GetHighlightText(TITANBG_FRIENDS);
			bInfo = bInfo.._friendstring;
		end

		if ( TitanGetVar(TITAN_TITANBG_ID, "D_Capture") ) then
			local pFaction = UnitFactionGroup("player");
			local showc = false;
			local cInfo = "\n\n"..TitanUtils_GetHighlightText(TITANBG_CAPTURE_TIMERS);
			for name in _localmap do
				if ( _localmap[name].capture and _localmap[name].capture > GetTime() and _localmap[name].faction ) then
					if ( _localmap[name].faction == pFaction ) then
						cInfo = cInfo.."\n"..name.."\t"..TitanUtils_GetRedText(SecondsToTime(_localmap[name].capture - GetTime()));
					else
						cInfo = cInfo.."\n"..name.."\t"..TitanUtils_GetGreenText(SecondsToTime(_localmap[name].capture - GetTime()));
					end
					showc = true;
				end
			end

			if ( showc ) then
				bInfo = bInfo..cInfo;
			end
		end

		if ( _playerstats.total and _playerstats.h and _playerstats.a and _playerstats.total > 0 ) then
			local pOpen = " [";
			local pClose = "]";

			bInfo = bInfo.."\n\n"..TITANBG_PLAYERS.."\t"..TitanUtils_GetHighlightText(_playerstats.total);
			bInfo = bInfo..pOpen..TITANBG_BLUETEXT.._playerstats.a..FONT_COLOR_CODE_CLOSE..pClose;
			bInfo = bInfo..pOpen..RED_FONT_COLOR_CODE.._playerstats.h..FONT_COLOR_CODE_CLOSE..pClose;
		end

		if ( TitanGetVar(TITAN_TITANBG_ID, "HideMinimapButton") ) then
			bInfo = bInfo.."\n\n"..TitanUtils_GetGreenText(TITANBG_SCOREFRAME_HINT);
		end

		return bInfo;
	end
end

function TitanPanelTitanBGButton_ToggleVar()
	TitanToggleVar(TITAN_TITANBG_ID, this.value);
	TitanPanelButton_UpdateButton(TITAN_TITANBG_ID);
end

function TitanPanelRightClickMenu_PrepareTitanBGMenu()
	local info = {};
	local status, name, instance = GetBattlefieldStatus();

	if ( UIDROPDOWNMENU_MENU_LEVEL == 2 ) then
		if ( UIDROPDOWNMENU_MENU_VALUE == "BGOptions" ) then
			TitanPanelRightClickMenu_AddTitle(TITANBG_MENU_BATTLEGROUND_OPTIONS, UIDROPDOWNMENU_MENU_LEVEL);

			info = {};
			info.text = TITANBG_MENU_AUTOJOIN;
			info.value = "B_AutoJoin";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "B_AutoJoin");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_MENU_PLAYSOUND;
			info.value = "B_PlaySoundOnJoin";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "B_PlaySoundOnJoin");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);

			TitanPanelRightClickMenu_AddSpacer(UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_MENU_AUTORES;
			info.value = "B_AutoRes";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "B_AutoRes");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_MENU_AUTORELEASE;
			info.value = "B_AutoRelease";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "B_AutoRelease");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
		elseif ( UIDROPDOWNMENU_MENU_VALUE == "DispOptions" ) then
			TitanPanelRightClickMenu_AddTitle(TITANBG_MENU_DISP_OPTIONS, UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_MENU_HIDEMINIMAPBUTTON;
			info.value = "HideMinimapButton";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "HideMinimapButton");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_MENU_SHOWFRIENDS;
			info.value = "D_Friends";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "D_Friends");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_MENU_SHOWCAPTURE;
			info.value = "D_Capture";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "D_Capture");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);

			TitanPanelRightClickMenu_AddSpacer(UIDROPDOWNMENU_MENU_LEVEL);
			TitanPanelRightClickMenu_AddTitle(TITANBG_MENU_PANEL_OPTIONS, UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_PANEL_S;
			info.value = "P_S";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "P_S");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_PANEL_K;
			info.value = "P_K";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "P_K");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_PANEL_KB;
			info.value = "P_KB";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "P_KB");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_PANEL_D;
			info.value = "P_D";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "P_D");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
			info = {};
			info.text = TITANBG_PANEL_H;
			info.value = "P_H";
			info.func = TitanPanelTitanBGButton_ToggleVar;
			info.checked = TitanGetVar(TITAN_TITANBG_ID, "P_H");
			info.keepShownOnClick = 1;
			UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
		end
		return;
	end

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_TITANBG_ID].menuText);

	if ( status == "queued" and TitanGetVar(TITAN_TITANBG_ID, "HideMinimapButton") ) then
		info = {};
		info.text = CHANGE_INSTANCE;
		info.func = ShowBattlefieldList;
		UIDropDownMenu_AddButton(info);

		info = {};
		info.text = LEAVE_QUEUE;
		info.func = AcceptBattlefieldPort;
		UIDropDownMenu_AddButton(info);

		TitanPanelRightClickMenu_AddSpacer();
	elseif ( status == "confirm" and TitanGetVar(TITAN_TITANBG_ID, "HideMinimapButton") ) then
		info = {};
		info.text = ENTER_BATTLE;
		info.func = BattlefieldFrame_EnterBattlefield;
		UIDropDownMenu_AddButton(info);

		info = {};
		info.text = LEAVE_QUEUE;
		info.func = AcceptBattlefieldPort;
		UIDropDownMenu_AddButton(info);
		TitanPanelRightClickMenu_AddSpacer();
	end


	TitanPanelRightClickMenu_AddToggleIcon(TITAN_TITANBG_ID);
	--TitanPanelRightClickMenu_AddToggleLabelText(TITAN_TITANBG_ID);
	info = {};
	info.text = TITAN_PANEL_MENU_SHOW_LABEL_TEXT;
	info.value = "P_Labels";
	info.checked = TitanGetVar(TITAN_TITANBG_ID, "P_Labels");
	info.keepShownOnClick = 1;
	info.func = TitanPanelTitanBGButton_ToggleVar;
	UIDropDownMenu_AddButton(info);

	
	TitanPanelRightClickMenu_AddSpacer();
	info = {};
	info.text = TITANBG_MENU_BATTLEGROUND_OPTIONS;
	info.value = "BGOptions";
	info.hasArrow = 1;
	UIDropDownMenu_AddButton(info);

	info = {};
	info.text = TITANBG_MENU_DISP_OPTIONS;
	info.value = "DispOptions";
	info.hasArrow = 1;
	UIDropDownMenu_AddButton(info);
	
	TitanPanelRightClickMenu_AddSpacer();
	TitanPanelRightClickMenu_AddCommand(TITAN_PANEL_MENU_HIDE, TITAN_TITANBG_ID, TITAN_PANEL_MENU_FUNC_HIDE);
end